@@ -31,6 +31,8 @@ func SavePngFile(m image.Image, filename string) error {
 	if err != nil {
 		return err
 	}
-	defer f.Close()
+	defer func() {
+		_ = f.Close()
+	}()
 	return png.Encode(f, m)
 }
